==> gesundheit-0.1.1.tgz: package/lib/update.js <==
(function() {
  var SUDQuery, Update, fluid, makeFrom, _ref;
  var __hasProp = Object.prototype.hasOwnProperty, __extends = function(child, parent) {
    for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; }
    function ctor() { this.constructor = child; }
    ctor.prototype = parent.prototype;
    child.prototype = new ctor;
    child.__super__ = parent.prototype;
    return child;
  };
  fluid = require('./fluid');
  _ref = require('./sud-query'), SUDQuery = _ref.SUDQuery, makeFrom = _ref.makeFrom;
  module.exports = Update = (function() {
    __extends(Update, SUDQuery);
    function Update(table, opts) {
      if (opts == null) {
        opts = {};
      }
      Update.__super__.constructor.call(this, table, opts);
      this.s.table = table;
      this.s.queryType = 'Update';
      this.s.fields = [];
    }
    Update.prototype.set = fluid(function(data) {
      var field, table, value, _results;
      table = this.s.table;
      _results = [];
      for (field in data) {
        value = data[field];
        field = this.resolve.field(table, field);
        value = this.resolve.value(table, field, value);
        this.s.fields.push(field);
        _results.push(this.s.parameters.push(value));
      }
      return _results;
    });
    Update.prototype.setRaw = fluid(function(data) {
      var field, value, _results;
      _results = [];
      for (field in data) {
        value = data[field];
        _results.push(this.s.fields.push(field + '=' + data));
      }
      return _results;
    });
    Update.prototype.toSql = function() {
      if (!this.s.fields.length) {
        throw new Error("Cannot render UPDATE without setting columns");
      }
      return Update.__super__.toSql.call(this);
    };
    return Update;
  })();
  Update.table = function() {
    return (function(func, args, ctor) {
      ctor.prototype = func.prototype;
      var child = new ctor, result = func.apply(child, args);
      return typeof result === "object" ? result : child;
    })(Update, arguments, function() {});
  };
}).call(this);

==> gesundheit-0.1.2.tgz: package/lib/update.js <==
(function() {
  var SUDQuery, Update, fluid, makeFrom, _ref;
  var __hasProp = Object.prototype.hasOwnProperty, __extends = function(child, parent) {
    for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; }
    function ctor() { this.constructor = child; }
    ctor.prototype = parent.prototype;
    child.prototype = new ctor;
    child.__super__ = parent.prototype;
    return child;
  };
  fluid = require('./fluid');
  _ref = require('./sud-query'), SUDQuery = _ref.SUDQuery, makeFrom = _ref.makeFrom;
  module.exports = Update = (function() {
    __extends(Update, SUDQuery);
    function Update(table, opts) {
      if (opts == null) {
        opts = {};
      }
      Update.__super__.constructor.call(this, table, opts);
      this.s.table = table;
      this.s.queryType = 'Update';
      this.s.fields = [];
    }
    Update.prototype.set = fluid(function(data) {
      var field, table, value, _results;
      table = this.s.table;
      _results = [];
      for (field in data) {
        value = data[field];
        field = this.resolve.field(table, field);
        value = this.resolve.value(table, field, value);
        this.s.fields.push(field);
        _results.push(this.s.parameters.push(value));
      }
      return _results;
    });
    Update.prototype.setRaw = fluid(function(data) {
      var field, value, _results;
      _results = [];
      for (field in data) {
        value = data[field];
        _results.push(this.s.fields.push(field + ' = ' + value));
      }
      return _results;
    });
    Update.prototype.toSql = function() {
      if (!this.s.fields.length) {
        throw new Error("Cannot render UPDATE without setting columns");
      }
      return Update.__super__.toSql.call(this);
    };
    return Update;
  })();
  Update.table = function() {
    return (function(func, args, ctor) {
      ctor.prototype = func.prototype;
      var child = new ctor, result = func.apply(child, args);
      return typeof result === "object" ? result : child;
    })(Update, arguments, function() {});
  };
}).call(this);
